# tfchain-py

[![Build Status](https://travis-ci.com/GlenDC/tfchain-py.svg?branch=master)](https://travis-ci.com/GlenDC/tfchain-py)

A TFChain client implementation in python.

This client has been ported from a [JumpScaleX Client](http://github.com/threefoldtech/jumpscaleX),
as to be able to use it in environments that require a Python3 client decoupled from any opinionated framework.

NOTE that this library and its API is not finished. Changes can be expected until we reach `v1.0.0`.
